@@ -805,9 +805,6 @@ Table <- R6::R6Class('Table',
                 }
             }
 
-            if (incAsText)
-                table$asText <- self$asString()
-
             element <- super$asProtoBuf(incAsText=incAsText, status=status)
             element$table <- table
             element
